@@ -1,4 +1,5 @@
 # Authors: John Dennis <jdennis@redhat.com>
+#          Thomas Liu <tliu@redhat.com>
 #
 # Copyright (C) 2006,2007,2008 Red Hat, Inc.
 #
@@ -78,7 +79,7 @@ class Plugin(object):
         self.priority = 50
         
     def report(self, avc, category, summary_template, problem_description_template,
-               fix_description_template, fix_cmd_template, level="yellow"):
+               fix_description_template, fix_cmd_template, level="yellow", fixable=False, button_text=_("Fix it")):
         """
         Report a denial and solution to the fault server.
         """
@@ -125,7 +126,9 @@ class Plugin(object):
             environment    = environment,
             line_numbers   = avc.audit_event.line_numbers,
             last_seen_date = TimeStamp(avc.audit_event.timestamp),
-            level          = level
+            level          = level,
+            fixable        = fixable,
+            button_text    = button_text
             )
 
         return siginfo
