@@ -271,7 +271,7 @@ class SETroubleshootDatabase(object):
                                        self.sigs.signature_list[-1].last_seen_date.format())
                 sigs = [siginfo.sig for siginfo in self.sigs.signature_list[:keep]]
                 for sig in sigs:
-                    self.delete_signature(sig)
+                    self.delete_signature(sig, prune=True)
 
         if self.max_alerts:
             keep = len(self.sigs.signature_list) - self.max_alerts
@@ -280,7 +280,7 @@ class SETroubleshootDatabase(object):
                 if debug:
                     log_database.debug("prune first %d alerts, len(sigs=%d sigs=%s", keep, len(sigs), sigs)
                 for sig in sigs:
-                    self.delete_signature(sig)
+                    self.delete_signature(sig, prune=True)
 
     def set_notify(self, notify):
         self.notify = notify
@@ -308,7 +308,7 @@ class SETroubleshootDatabase(object):
         self.validate()
         self.prune()
 
-    def save(self):
+    def save(self, prune=False):
         if self.filepath is None:
             return
 
@@ -316,7 +316,8 @@ class SETroubleshootDatabase(object):
             log_database.debug("writing database (%s) modified_count=%s",
                                self.filepath, self.modified_count)
 
-        self.prune()
+        if not prune: 
+            self.prune()
         self.sigs.write_xml('sigs', self.filepath)
         self.file_exists = True
         self.modified_count = 0
@@ -324,13 +325,13 @@ class SETroubleshootDatabase(object):
             gobject.source_remove(self.auto_save_timer)
             self.auto_save_timer = None
         
-    def mark_modified(self):
+    def mark_modified(self, prune=False):
         self.modified_count += 1
         if self.filepath is None:
             return
 
         if self.modified_count > self.auto_save_threshold or not self.file_exists:
-            self.save()
+            self.save(prune)
         elif self.auto_save_timer is None:
             self.auto_save_timer = \
                 gobject.timeout_add(self.auto_save_interval*1000,
@@ -406,7 +407,7 @@ class SETroubleshootDatabase(object):
         sigs.add_siginfo(siginfo)
         return sigs
 
-    def delete_signature(self, sig):
+    def delete_signature(self, sig, prune=False):
         if debug:
             log_database.debug("delete_signature: sig=%s", sig)
 
@@ -414,7 +415,7 @@ class SETroubleshootDatabase(object):
         self.sigs.remove_siginfo(siginfo)
         if self.notify:
             self.notify.signatures_updated('delete', siginfo.local_id)
-        self.mark_modified()
+        self.mark_modified(prune)
         
     def modify_siginfo(self, siginfo):
         if self.notify:
@@ -622,7 +623,8 @@ class LogfileAnalyzer(gobject.GObject):
                 yield False
 
             self.n_bytes_read += len(new_data)
-            self.progress = float(self.n_bytes_read) / float(self.file_size)
+            if self.file_size > 0:
+                self.progress = float(self.n_bytes_read) / float(self.file_size)
             self.emit('progress', self.progress)
 
             for (record_type, event_id, body_text, fields, line_number) in self.record_reader.feed(new_data):
