@@ -34,12 +34,16 @@ import struct
 import os
 import re
 import selinux
+import base64
 from types import *
 
 from setroubleshoot.log import *
 from setroubleshoot.util import *
 from setroubleshoot.html_util import *
 from setroubleshoot.xml_serialize import *
+from setroubleshoot.sesearch import *
+
+O_ACCMODE = 00000003
 
 #-----------------------------------------------------------------------------
 
@@ -522,35 +526,35 @@ class AVC:
     # They are here to be used below in the access matching functions.
     stat_file_perms     = ['getattr']
     x_file_perms        = ['getattr', 'execute']
-    r_file_perms        = ['read', 'getattr', 'lock', 'ioctl']
-    rx_file_perms       = ['read', 'getattr', 'lock', 'execute', 'ioctl']
-    ra_file_perms       = ['ioctl', 'read', 'getattr', 'lock', 'append']
+    r_file_perms        = ['open', 'read', 'getattr', 'lock', 'ioctl']
+    rx_file_perms       = ['open', 'read', 'getattr', 'lock', 'execute', 'ioctl']
+    ra_file_perms       = ['open', 'ioctl', 'read', 'getattr', 'lock', 'append']
     link_file_perms     = ['getattr', 'link', 'unlink', 'rename']
     create_lnk_perms    = ['create', 'read', 'getattr', 'setattr', 'link', 'unlink', 'rename']
-    create_file_perms   = ['create', 'ioctl', 'read', 'getattr', 'lock', 'write', 'setattr', 'append',
+    create_file_perms   = ['open', 'create', 'ioctl', 'read', 'getattr', 'lock', 'write', 'setattr', 'append',
                            'link', 'unlink', 'rename']
-    r_dir_perms         = ['read', 'getattr', 'lock', 'search', 'ioctl']
-    rw_dir_perms        = ['read', 'getattr', 'lock', 'search', 'ioctl', 'add_name', 'remove_name', 'write']
-    ra_dir_perms        = ['read', 'getattr', 'lock', 'search', 'ioctl', 'add_name', 'write']
-    create_dir_perms    = ['create', 'read', 'getattr', 'lock', 'setattr', 'ioctl', 'link', 'unlink',
+    r_dir_perms         = ['open', 'read', 'getattr', 'lock', 'search', 'ioctl']
+    rw_dir_perms        = ['open', 'read', 'getattr', 'lock', 'search', 'ioctl', 'add_name', 'remove_name', 'write']
+    ra_dir_perms        = ['open', 'read', 'getattr', 'lock', 'search', 'ioctl', 'add_name', 'write']
+    create_dir_perms    = ['open', 'create', 'read', 'getattr', 'lock', 'setattr', 'ioctl', 'link', 'unlink',
                            'rename', 'search', 'add_name', 'remove_name', 'reparent', 'write', 'rmdir']
     mount_fs_perms      = ['mount', 'remount', 'unmount', 'getattr']
     search_dir_perms    = ['getattr', 'search']
     getattr_dir_perms   = ['getattr']
     setattr_dir_perms   = ['setattr']
-    list_dir_perms      = ['getattr', 'search', 'read', 'lock', 'ioctl']
-    add_entry_dir_perms = ['getattr', 'search', 'lock', 'ioctl', 'write', 'add_name']
-    del_entry_dir_perms = ['getattr', 'search', 'lock', 'ioctl', 'write', 'remove_name']
-    manage_dir_perms    = ['create', 'getattr', 'setattr', 'read', 'write', 'link', 'unlink', 'rename',
+    list_dir_perms      = ['open', 'getattr', 'search', 'read', 'lock', 'ioctl']
+    add_entry_dir_perms = ['open', 'getattr', 'search', 'lock', 'ioctl', 'write', 'add_name']
+    del_entry_dir_perms = ['open', 'getattr', 'search', 'lock', 'ioctl', 'write', 'remove_name']
+    manage_dir_perms    = ['open', 'create', 'getattr', 'setattr', 'read', 'write', 'link', 'unlink', 'rename',
                            'search', 'add_name', 'remove_name', 'reparent', 'rmdir', 'lock', 'ioctl']
     getattr_file_perms  = ['getattr']
     setattr_file_perms  = ['setattr']
-    read_file_perms     = ['getattr', 'read', 'lock', 'ioctl']
-    append_file_perms   = ['getattr', 'append', 'lock', 'ioctl']
-    write_file_perms    = ['getattr', 'write', 'append', 'lock', 'ioctl']
-    rw_file_perms       = ['getattr', 'read', 'write', 'append', 'ioctl', 'lock']
+    read_file_perms     = ['open', 'getattr', 'read', 'lock', 'ioctl']
+    append_file_perms   = ['open', 'getattr', 'append', 'lock', 'ioctl']
+    write_file_perms    = ['open', 'getattr', 'write', 'append', 'lock', 'ioctl']
+    rw_file_perms       = ['open', 'getattr', 'read', 'write', 'append', 'ioctl', 'lock']
     delete_file_perms   = ['getattr', 'unlink']
-    manage_file_perms   = ['create', 'getattr', 'setattr', 'read', 'write', 'append', 'rename', 'link',
+    manage_file_perms   = ['open', 'create', 'getattr', 'setattr', 'read', 'write', 'append', 'rename', 'link',
                            'unlink', 'ioctl', 'lock']
 
     pipe_instance_path_re = re.compile(r'^(\w+):\[([^\]]*)\]')
@@ -574,6 +578,7 @@ class AVC:
         self.src_rpms=[]
         self.tgt_rpms=[]
         self.host = None
+        self.syscall = None
 
         self.derive_avc_info_from_audit_event()
 
@@ -613,6 +618,17 @@ class AVC:
                 return False
                 
         return True
+    
+    def allowed_target_types(self):
+        return map(lambda x: x[TCONTEXT], sesearch([ALLOW], {SCONTEXT: self.scontext.type, CLASS: self.tclass, PERMS: self.access}))
+        
+
+    def open_with_write(self):
+        if self.has_any_access_in(['open']):
+            if self.a1 and (int(self.a1) & O_ACCMODE) != os.O_RDONLY:
+                return True
+        return False
+
 
     def __typeMatch(self, context, type_list):
         for type in type_list:
@@ -707,19 +723,50 @@ class AVC:
                     path = name
 
         if path is not None:
-            if path.startswith("/") == False:
-                import commands
-                command = "locate -b '\%s'" % path 
-                rc, output = commands.getstatusoutput(command)
-                if rc == 0:
-                    inode = int(self.avc_record.get_field("ino"))
-                    for file in output.split("\n"):
-                        try:
-                            if int(os.stat(file).st_ino) == inode:
-                                path = file
+
+            if path == "/":
+                matches = []
+                try:
+                    dev = self.avc_record.get_field('dev')
+                    ino = int(self.avc_record.get_field('ino'))
+                    fd=open("/proc/mounts", "r")
+                    for i in fd.read().split("\n"):
+                        x = i.split()
+                        if len(x) and x[1][0] == '/':
+                            try:
+                                if int(os.lstat(x[1]).st_ino) == ino:
+                                    matches.append(x[:3])
+                            except OSError:
+                                continue 
+                    fd.close()
+                    if len(matches) == 1:
+                        path = matches[0][1]
+                    elif len(matches) > 1:
+                        for i in matches:
+                            if i[0] == ("/dev/%s" % dev) or i[2] == dev:
+                                path = i[1]
                                 break
-                        except:
-                            pass
+                except TypeError:
+                    path = "unknown mountpoint"
+                    pass
+                except OSError:
+                    path = "unknown mountpoint"
+                    pass
+
+            else:
+                if path.startswith("/") == False:
+                    import commands
+                    command = "locate -b '\%s'" % path 
+                    rc, output = commands.getstatusoutput(command)
+                    if rc == 0:
+                        inode = int(self.avc_record.get_field("ino"))
+                        for file in output.split("\n"):
+                            try:
+                                if int(os.lstat(file).st_ino) == inode:
+                                    path = file
+                                    break
+                            except:
+                                pass
 
         if path is not None:
             if path.startswith('/'):
@@ -731,23 +778,28 @@ class AVC:
                 # applies to socket as well
                 match = self.pipe_instance_path_re.search(path)
                 if match:
-                    path = match.group(1)
+                    path = self.tclass
 
-        self.tpath = path
+        try:
+            t = path.decode("hex")
+            t.decode()
+            self.tpath = t
+        except:
+            self.tpath = path
 
     def derive_avc_info_from_audit_event(self):
         self.tpath = None
         self.spath = None
         self.source = None
+        self.a1 = None
+        self.success = False
         self.syscall_paths = []
-
         exe = comm = arch = syscall = None
 
         self.avc_record = self.audit_event.get_avc_record()
         syscall_record = self.audit_event.get_record_of_type('SYSCALL')
 
         self.access = self.avc_record.get_field('seperms')
-
         if not isinstance(self.scontext, AvcContext):
             self.scontext = AvcContext(self.avc_record.get_field('scontext'))
 
@@ -763,31 +815,43 @@ class AVC:
 
         self._set_tpath()
 
+
+        # exe, cwd, name, path, key, dir, comm, ocomm, key_desc
+
         if syscall_record:
             exe     = syscall_record.get_field('exe')
+            try:
+                exe.decode("hex")
+            except:
+                pass
             comm    = syscall_record.get_field('comm')
             arch    = syscall_record.get_field('arch')
             syscall = syscall_record.get_field('syscall')
-
+            self.success = (syscall_record.get_field('success') == "yes")
+            self.a1 = syscall_record.get_field('a1')
             if arch is not None and syscall is not None:
                 arch = int(arch, 16)
                 syscall = int(syscall)
                 self.syscall = audit.audit_syscall_to_name(syscall, audit.audit_elf_to_machine(arch))
                 self.syscall = audit.audit_syscall_to_name(syscall, audit.audit_elf_to_machine(arch))
-            else:
-                self.syscall = None
 
         if comm is None:
             comm = self.avc_record.get_field('comm')
         if exe is None:
             exe = self.avc_record.get_field('exe')
 
-        self.spath = exe
+        try:
+            self.spath = exe.decode("hex")
+        except:
+            self.spath = exe
 
         if comm:
             self.source = comm
         elif exe:
-            self.source = exe
+            self.source = self.spath
+
+        if not self.spath:
+            self.spath = self.source
 
         cwd_record = self.audit_event.get_record_of_type('CWD')
         if cwd_record:
@@ -836,7 +900,11 @@ class AVC:
         self.template_substitutions["TARGET_TYPE"] = escape_html(self.tcontext.type)
         self.template_substitutions["SOURCE"]      = escape_html(self.source)
         self.template_substitutions["SOURCE_PATH"] = escape_html(self.spath)
+        if self.spath:
+            self.template_substitutions["FIX_SOURCE_PATH"] = re.sub(" ",".",escape_html(self.spath))
         self.template_substitutions["TARGET_PATH"] = escape_html(self.tpath)
+        if self.tpath:
+            self.template_substitutions["FIX_TARGET_PATH"] = re.sub(" ",".",escape_html(self.tpath))
 
         if self.tpath is None:
             self.template_substitutions["TARGET_DIR"] = None
