@@ -27,6 +27,7 @@ import audit
 import select
 import selinux
 import socket as Socket
+import fcntl
 import thread
 import threading
 import time
@@ -278,6 +279,7 @@ class AuditSocketReceiverThread(threading.Thread):
                             record_format = derive_record_format(self.audit_socket_path)
                             self.record_reader = AuditRecordReader(record_format)
                             self.audit_socket=Socket.socket(Socket.AF_UNIX,Socket.SOCK_STREAM)
+                            fcntl.fcntl(self.audit_socket.fileno(), fcntl.F_SETFD, fcntl.FD_CLOEXEC)
                             self.audit_socket.connect(self.audit_socket_path)
                             self.audit_socket_fd = self.audit_socket.makefile()
                             log_avc.info("audit socket (%s) connected", self.audit_socket_path)
