@@ -24,6 +24,7 @@ import errno as Errno
 import gobject
 import os
 import socket as Socket
+import fcntl
 import threading
 from types import *
 
@@ -659,7 +660,7 @@ class ListeningServer(ConnectionIO):
             log_communication.debug("new_listening_socket: %s", self.socket_address)
 
         self.socket_address.socket = Socket.socket(self.socket_address.family, self.socket_address.type)
-
+        fcntl.fcntl(self.socket_address.socket.fileno(), fcntl.F_SETFD, fcntl.FD_CLOEXEC)
         if self.allow_reuse_address:
             self.socket_address.socket.setsockopt(Socket.SOL_SOCKET, Socket.SO_REUSEADDR, 1)
         self.socket_address.socket.bind(self.socket_address.get_py_address())
@@ -691,6 +692,7 @@ class ListeningServer(ConnectionIO):
             if io_condition & gobject.IO_IN:
                 try:
                     client_socket, client_address = socket.accept()
+                    fcntl.fcntl(client_socket.fileno(), fcntl.F_SETFD, fcntl.FD_CLOEXEC)
                     client_handler = self.client_connection_handler_class(self.socket_address)
                     client_handler.open(client_socket, client_address)
                     self.connection_state.update(0, ConnectionState.PROBLEM_FLAGS)
