@@ -39,9 +39,7 @@ if __name__ == "__main__":
     import gettext
     from setroubleshoot.config import parse_config_setting, get_config
     gettext.install(domain    = get_config('general', 'i18n_text_domain'),
-		    localedir = get_config('general', 'i18n_locale_dir'),
-		    unicode   = False,
-		    codeset   = get_config('general', 'i18n_encoding'))
+		    localedir = get_config('general', 'i18n_locale_dir'))
     from setroubleshoot.log import log_init
     log_init('test', {'console':True,
              'level':'debug'})
