@@ -200,7 +200,7 @@ class AlertPluginReportReceiver(PluginReportReceiver):
         # FIXME: should this be using our logging objects in log.py?
         from setroubleshoot.html_util import html_to_text
         summary = html_to_text(siginfo.solution.summary, 1024)
-        syslog.syslog(summary + _(" For complete SELinux messages. run sealert -l %s" % siginfo.local_id ))
+        syslog.syslog(syslog.LOG_ERR, summary + _(" For complete SELinux messages. run sealert -l %s" % siginfo.local_id ))
         return siginfo
 
 #-----------------------------------------------------------------------------
@@ -447,6 +447,27 @@ class SetroubleshootdDBusObject(dbus.service.Object):
         self.conn_ctr += 1
         log_server.debug('dbus iface start() called: %d Connections' % self.conn_ctr)
         return _("Started")
+    
+    @dbus.service.method(dbus_system_interface, in_signature='s', out_signature='ii')
+    def check_for_new(self, last_seen_id):
+        database = get_host_database()
+        s = ""
+        signatures = []
+        for sig in  database.query_alerts("*").siginfos():
+            signatures.append(sig)
+        signatures.sort(compare_sig)
+        
+        count = 0
+        red = 0
+        for sig in signatures:
+            count += 1
+            if sig.level == "red":
+                red += 1
+            if sig.local_id == last_seen_id:
+                red = 0
+                count = 0
+            
+        return count, red
 
     @dbus.service.method(dbus_system_interface, in_signature='s',  out_signature='s')
     def avc(self, data):
@@ -482,6 +503,9 @@ class SetroubleshootdDBusObject(dbus.service.Object):
         if self.conn_ctr == 0:
             signal.alarm(timeout) 
 
+def compare_sig(a, b):
+    return cmp(a.last_seen_date, b.last_seen_date)
+
 class SetroubleshootdDBus:
     def __init__(self, analysis_queue, alert_receiver):
         try:
