@@ -1,6 +1,8 @@
 # Authors: John Dennis <jdennis@redhat.com>
+#          Thomas Liu <tliu@redhat.com>
+#          Dan Walsh <dwalsh@redhat.com>
 #
-# Copyright (C) 2006,2007,2008 Red Hat, Inc.
+# Copyright (C) 2006,2007,2008,2009 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,9 +44,7 @@ if __name__ == "__main__":
     import gettext
     from setroubleshoot.config import parse_config_setting, get_config
     gettext.install(domain    = get_config('general', 'i18n_text_domain'),
-		    localedir = get_config('general', 'i18n_locale_dir'),
-		    unicode   = False,
-		    codeset   = get_config('general', 'i18n_encoding'))
+		    localedir = get_config('general', 'i18n_locale_dir'))
     from setroubleshoot.log import log_init
     log_init('test', {'console':True,
 			   'level':'debug'})
@@ -58,7 +58,7 @@ from setroubleshoot.util import *
 from setroubleshoot.html_util import *
 import setroubleshoot.uuid as uuid
 from setroubleshoot.audit_data import *
-
+import hashlib
 from types import *
 
 # Don't reuse the numeric values!
@@ -109,6 +109,7 @@ class SEEnvironment(XmlSerialize):
 
     def __init__(self):
         super(SEEnvironment, self).__init__()
+        self.update()
 
     def update(self):
         import platform
@@ -256,6 +257,8 @@ class SEFaultSignatureInfo(XmlSerialize):
         'local_id'         : {'XMLForm':'element' },
         'users'            : {'XMLForm':'element', 'list':'user', 'import_typecast':SEFaultSignatureUser, },
         'level'         : {'XMLForm':'element' },
+        'fixable'       : {'XMLForm':'element' },
+        'button_text'   : {'XMLForm':'element' },
         }
 
     merge_include = ['audit_event', 'tpath', 'src_rpm_list', 'tgt_rpm_list',
@@ -276,6 +279,13 @@ class SEFaultSignatureInfo(XmlSerialize):
         self.line_numbers = merge_lists(self.line_numbers, siginfo.line_numbers)
         self.last_seen_date = TimeStamp(siginfo.last_seen_date)
 
+    def get_hash_str(self):
+        return  "%s,%s,%s,%s,%s,%s,%s" % (self.environment.policy_rpm,self.sig.analysis_id, self.source, self.scontext.type, self.tcontext.type, self.tclass, ",".join(self.sig.access))
+
+    def get_hash(self):
+        hash = hashlib.sha256(self.get_hash_str())
+        return hash.hexdigest()
+        
     def get_user_data(self, username):
         for user in self.users:
             if user.username == username:
@@ -346,9 +356,16 @@ class SEFaultSignatureInfo(XmlSerialize):
         return "%s [ %s ]" % (self.tpath, self.tclass)
 
     def description_adjusted_for_permissive(self):
-        permissive_msg = _("SELinux is in permissive mode, the operation would have been denied but was permitted due to permissive mode.")
-        if self.environment.enforce == 'Permissive':
-            return '<font color="FF0000">[%s]</font><p>%s' % (permissive_msg, self.solution.problem_description)
+        permissive_msg = None
+        syscall_record = self.audit_event.get_record_of_type('SYSCALL')
+        if syscall_record != None and syscall_record.get_field('success') == 'yes':
+            permissive_msg = _("%s has a permissive type (%s). This access was not denied.") % (self.source, self.scontext.type)
+
+        if self.environment.enforce == "Permissive":
+            permissive_msg = _("SELinux is in permissive mode. This access was not denied.")
+
+        if permissive_msg:
+            return _('<font color="0000FF">[%s]</font><p>%s') % (permissive_msg, self.solution.problem_description)
         else:
             return self.solution.problem_description
 
@@ -422,7 +439,6 @@ class SEFaultSignatureInfo(XmlSerialize):
         html += tr1_fmt % (_("Policy RPM"),            escape_html(default_text(env.policy_rpm)))
         html += tr1_fmt % (_("Selinux Enabled"),       escape_html(default_text(env.selinux_enabled)))
         html += tr1_fmt % (_("Policy Type"),           escape_html(default_text(env.policy_type)))
-        html += tr1_fmt % (_("MLS Enabled"),           escape_html(default_text(env.selinux_mls_enabled)))
         html += tr1_fmt % (_("Enforcing Mode"),        escape_html(default_text(env.enforce)))
         html += tr1_fmt % (_("Plugin Name"),           escape_html(default_text(self.sig.analysis_id)))
         html += tr1_fmt % (_("Host Name"),             escape_html(default_text(env.hostname)))
@@ -484,7 +500,6 @@ class SEFaultSignatureInfo(XmlSerialize):
         text += format_2_column_name_value(_("Policy RPM"),            default_text(env.policy_rpm))
         text += format_2_column_name_value(_("Selinux Enabled"),       default_text(env.selinux_enabled))
         text += format_2_column_name_value(_("Policy Type"),           default_text(env.policy_type))
-        text += format_2_column_name_value(_("MLS Enabled"),           default_text(env.selinux_mls_enabled))
         text += format_2_column_name_value(_("Enforcing Mode"),        default_text(env.enforce))
         text += format_2_column_name_value(_("Plugin Name"),           default_text(self.sig.analysis_id))
         text += format_2_column_name_value(_("Host Name"),             default_text(env.hostname))
